summaryrefslogtreecommitdiffstats
path: root/src/dolphiniconsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphiniconsview.h')
-rw-r--r--src/dolphiniconsview.h41
1 files changed, 21 insertions, 20 deletions
diff --git a/src/dolphiniconsview.h b/src/dolphiniconsview.h
index 9be2102..adfd512 100644
--- a/src/dolphiniconsview.h
+++ b/src/dolphiniconsview.h
@@ -22,7 +22,7 @@
#define DOLPHINICONSVIEW_H
#include <kfileiconview.h>
-#include <qpixmap.h>
+#include <tqpixmap.h>
#include <kurl.h>
#include <itemeffectsmanager.h>
@@ -39,6 +39,7 @@ class DolphinView;
class DolphinIconsView : public KFileIconView, public ItemEffectsManager
{
Q_OBJECT
+ TQ_OBJECT
public:
enum LayoutMode {
@@ -46,12 +47,12 @@ public:
Previews
};
- DolphinIconsView(DolphinView *parent, LayoutMode layoutMode);
+ DolphinIconsView(DolphinView *tqparent, LayoutMode tqlayoutMode);
virtual ~DolphinIconsView();
void setLayoutMode(LayoutMode mode);
- LayoutMode layoutMode() const { return m_layoutMode; }
+ LayoutMode tqlayoutMode() const { return m_tqlayoutMode; }
/** @see ItemEffectsManager::updateItems */
virtual void beginItemUpdates();
@@ -64,7 +65,7 @@ public:
* the details view.
*/
// TODO: Other view implementations use a similar interface. When using
- // Interview in Qt4 this method should be moved to a base class (currently
+ // Interview in TQt4 this method should be moved to a base class (currently
// not possible due to having different base classes for the views).
void refreshSettings();
@@ -82,7 +83,7 @@ public:
public slots:
/**
* Bypass a layout issue in KFileIconView in combination with previews.
* @see KFileIconView::arrangeItemsInGrid
*/
virtual void arrangeItemsInGrid(bool updated = true);
@@ -97,10 +98,10 @@ signals:
protected:
/** @see ItemEffectsManager::setContextPixmap */
virtual void setContextPixmap(void* context,
- const QPixmap& pixmap);
+ const TQPixmap& pixmap);
/** @see ItemEffectsManager::contextPixmap */
- virtual const QPixmap* contextPixmap(void* context);
+ virtual const TQPixmap* contextPixmap(void* context);
/** @see ItemEffectsManager::firstContext */
virtual void* firstContext();
@@ -112,29 +113,29 @@ protected:
virtual KFileItem* contextFileInfo(void* context);
/** @see KFileIconView::contentsMousePressEvent */
- virtual void contentsMousePressEvent(QMouseEvent* event);
+ virtual void contentsMousePressEvent(TQMouseEvent* event);
/** @see KFileIconView::contentsMouseReleaseEvent */
- virtual void contentsMouseReleaseEvent(QMouseEvent* event);
+ virtual void contentsMouseReleaseEvent(TQMouseEvent* event);
/** @see KFileIconView::drawBackground */
- virtual void drawBackground(QPainter* painter, const QRect& rect);
+ virtual void drawBackground(TQPainter* painter, const TQRect& rect);
/** @see KFileIconView::dragObject */
- virtual QDragObject* dragObject();
+ virtual TQDragObject* dragObject();
/** @see KFileIconView::contentsDragEnterEvent */
- virtual void contentsDragEnterEvent(QDragEnterEvent* event);
+ virtual void contentsDragEnterEvent(TQDragEnterEvent* event);
/** @see KFileIconView::contentsDragMoveEvent */
- virtual void contentsDragMoveEvent(QDragMoveEvent* event);
+ virtual void contentsDragMoveEvent(TQDragMoveEvent* event);
/** @see KFileIconView::contentsDropEvent */
- virtual void contentsDropEvent(QDropEvent* event);
+ virtual void contentsDropEvent(TQDropEvent* event);
private slots:
/** Is connected to the onItem-signal from KFileIconView. */
- void slotOnItem(QIconViewItem* item);
+ void slotOnItem(TQIconViewItem* item);
/** Is connected to the onViewport-signal from KFileIconView. */
void slotOnViewport();
@@ -143,19 +144,19 @@ private slots:
* Opens the context menu for the item \a item on the given
* position \a pos.
*/
- void slotContextMenuRequested(QIconViewItem* item,
- const QPoint& pos);
+ void slotContextMenuRequested(TQIconViewItem* item,
+ const TQPoint& pos);
/** Renames the item \a item to the name \a name. */
- void slotItemRenamed(QIconViewItem* item,
- const QString& name);
+ void slotItemRenamed(TQIconViewItem* item,
+ const TQString& name);
void slotActivationUpdate();
void slotUpdateDisabledItems();
private:
int m_previewIconSize;
- LayoutMode m_layoutMode;
+ LayoutMode m_tqlayoutMode;
DolphinView* m_dolphinView;
/** Returns the increased icon size for the size \a size. */
@@ -82,7 +83,7 @@ public:
public slots:
/**
- * Bypass a layout issue in KFileIconView in combination with previews.
+ * Bypass a tqlayout issue in KFileIconView in combination with previews.
* @see KFileIconView::arrangeItemsInGrid
*/